@@ -238,7 +238,7 @@ font_add_google = function(name, family = name, regular.wt = 400,
     bi.url = font$files[[bolditalic]]
     bi.file = if(is.null(bi.url)) NULL else download_font_file(bi.url, repo, handle = handle)
 
-    font.add(family, r.file, b.file, i.file, bi.file)
+    font_add(family, r.file, b.file, i.file, bi.file)
 }
 
 #' @rdname font_add_google
